@@ -23,7 +23,7 @@
 
 #include <config.h>
 
-#if defined(HAVE_W32_SYSTEM) || defined (HAVE_W32CE_SYSTEM)
+#if defined(HAVE_W32_SYSTEM)
 #error This code is only used on POSIX
 #endif
 
@@ -32,7 +32,6 @@
 #include <stdint.h>
 #include <string.h>
 #include <errno.h>
-#include <assert.h>
 #ifdef HAVE_SIGNAL_H
 # include <signal.h>
 #endif
@@ -704,8 +703,13 @@ _gpgrt_wait_processes (const char **pgmnames, pid_t *pids, size_t count,
     {
       int status = -1;
 
+      /* Skip invalid PID.  */
       if (pids[i] == (pid_t)(-1))
-        return GPG_ERR_INV_VALUE;
+        {
+          r_exitcodes[i] = -1;
+          left -= 1;
+          continue;
+        }
 
       /* See if there was a previously stored result for this pid.  */
       if (get_result (pids[i], &status))
@@ -754,7 +758,7 @@ _gpgrt_wait_processes (const char **pgmnames, pid_t *pids, size_t count,
           /* Process PIDS[i] died.  */
           if (r_exitcodes[i] != (pid_t) -1)
             {
-              _gpgrt_log_error ("PID %d was reused", pid);
+              _gpgrt_log_error ("PID %d was reused", (int)pid);
               ec = GPG_ERR_GENERAL;
               break;
             }
